@@ -7,7 +7,7 @@ fi
 
 # accept any incoming COLORTERM environment variable
 sed -i 's/^AcceptEnv LANG LC_\*$/AcceptEnv COLORTERM LANG LC_*/' /etc/ssh/sshd_config
-if [ -f /sbin/openrc-init ]; then
+if [ -f /sbin/openrc-run ]; then
 	rc-service --ifstarted sshd reload
 elif command -v systemctl >/dev/null 2>&1; then
 	if systemctl -q is-active ssh; then
