@@ -18,7 +18,7 @@ fi
 install -m 755 "${LIMA_CIDATA_MNT}"/lima-guestagent /usr/local/bin/lima-guestagent
 
 # Launch the guestagent service
-if [ -f /sbin/openrc-init ]; then
+if [ -f /sbin/openrc-run ]; then
 	# Install the openrc lima-guestagent service script
 	cat >/etc/init.d/lima-guestagent <<'EOF'
 #!/sbin/openrc-run
